clear
set more off
cd "D:\Research\Inflation\Figures\Sensitivity\txt"
! dir INF*.txt /a-d /b > "D:\Research\Inflation\Figures\Sensitivity\filelist.txt", replace

// create the baseline values for median gap using EXP_RESULTS.TXT

infix 16 first PITRGY 5-12 BSLGAP 17-24 using EXP_RESULTS.TXT
drop if _n>11
save bslgap.dta, replace
drop _all

// select the values for median gap using INFLATION_SNS*.TXT files

file open myfile using "D:\Research\Inflation\Figures\Sensitivity\filelist.txt", read
file read myfile line
infix 16 first PITRGY 5-12 MDNGAP 17-24 using `line'
drop if _n>11
	  gen PARMTR = substr("`line'",15,6)
	  gen HIGIND = 0
	  replace HIGIND = 1 if substr("`line'",-5,1)=="H"
	merge 1:1 PITRGY using bslgap.dta
	drop _merge
	save `line'.dta, replace
save sns_data.dta, replace

drop _all

file read myfile line
while r(eof)==0 {
	infix 16 first PITRGY 5-12 MDNGAP 17-24 using `line', 
      drop if _n>11
	  gen PARMTR = substr("`line'",15,6)
	  gen HIGIND = 0
	  replace HIGIND = 1 if substr("`line'",-5,1)=="H"
	merge 1:1 PITRGY using bslgap.dta
	drop _merge
	save `line'.dta, replace
	append using sns_data.dta
	save sns_data.dta, replace
	drop _all
    file read myfile line
}

file close myfile

use sns_data.dta, clear

drop if PITRGY!=float(1.03) & PITRGY!=float(1.1)
sort PARMTR HIGIND PITRGY
by PARMTR HIGIND: gen CHANGE = MDNGAP[2] - MDNGAP[1]
by PARMTR HIGIND: gen CHABSL = BSLGAP[2] - BSLGAP[1]
gen DEVHIG = CHANGE-CHABSL if HIGIND == 1
gen DEVLOW = CHANGE-CHABSL if HIGIND == 0
bysort PARMTR HIGIND: drop if _n == 2

bysort PARMTR: egen ADEVHI = mean(abs(DEVHIG))
bysort PARMTR: egen ADEVLO = mean(abs(DEVLOW))
gen MAXDEV=max(ADEVHI, ADEVLO)

collapse DEVHIG DEVLOW MAXDEV, by(PARMTR)
gsort -MAXDEV
expandby 2, by(PARMTR)
gsort -MAXDEV PARMTR
gen ID = .
replace ID = _n if mod(_n,2)
order ID PARMTR

gen DEVHI2 = .
replace DEVHI2 = DEVHIG if DEVHIG<DEVLOW & (DEVHIG>0 & DEVLOW>0)
replace DEVHI2 = DEVHIG if DEVHIG>DEVLOW & (DEVHIG<0 & DEVLOW<0)
replace DEVHI2 = . if ID == .
local NUMLAB=_N
forvalues i = 1(2)`NUMLAB' {
local label_`i' = PARMTR[`i']
}
twoway (bar DEVHIG ID, color(dkorange)) (bar DEVLOW ID, color(green)) (bar DEVHI2 ID, color(dkorange)), legend(order(1 "High" 2 "Low") pos(2) ring(0) bm(t=4) size(small)) xtitle("") ytitle(Dev. from baseline right amplitude) ///
xlabel(1 "`label_1'" 3 "`label_3'" 5 "`label_5'" 7 "`label_7'" 9 "`label_9'" 11 "`label_11'" ///
13 "`label_13'" 15 "`label_15'" 17 "`label_17'" 19 "`label_19'" 21 "`label_21'" ///
23 "`label_23'" 25 "`label_25'" 27 "`label_27'" 29 "`label_29'" 31 "`label_31'" 33 "`label_33'" ///
35 "`label_35'" 37 "`label_37'" 39 "`label_39'" 41 "`label_41'" 43 "`label_43'" 45 "`label_45'" ///
47 "`label_47'" , angle(vertical)) ///
graphregion(color(white) margin(0 1 0 1)) bgcolor(white)

graph export fig2c.pdf, as(pdf) replace
