# delimit ;
set more off ;
set matsize 550 ;

clear ;

set mem 100m ;

cd "D:\Research\Inflation\Figures\Significance" ;

forvalues i = 0(0.01)0.1 { ;
	local j = 10000 * (`i' + 1) ;
	insheet using exp_results_pitrgy_`j'_history.csv, comma clear names ;

	gen inflationtarget = `i' * 100 ;
	move inflationtarget run ;
	lab var inflationtarget "Inflation Target" ;

	save exp_results_pitrgy_`j'_history.dta, replace ;
} ;

use exp_results_pitrgy_10000_history.dta, clear ;

forvalues i = 0.01(0.01)0.1 { ;
	local j = 10000 * (`i' + 1) ;
	append using exp_results_pitrgy_`j'_history.dta ;
} ;

save exp_results_history.dta, replace ;


/*************************************************************************************************************************************************
 * GRAPH SHOWING THE 95% CONFIDENCE INTERVAL BANDS OF THE MEDIAN LOG OUTPUT GAP AND UNEMPLOYMENT RATE ESTIMATES ACROSS RUNS PER INFLATION TARGET *
 *************************************************************************************************************************************************/

use exp_results_history.dta, clear ;

drop if crashed == 1 ;

gen medloggap = . ;
gen u95loggap = . ;
gen l95loggap = . ;

gen medunempl = . ;
gen u95unempl = . ;
gen l95unempl = . ;

forvalues i = 0(1)10 { ;
	centile logoutputgap if inflationtarget == `i', centile(50) normal ;

	replace medloggap = r(c_1)  if inflationtarget == `i' ;
	replace u95loggap = r(ub_1) if inflationtarget == `i' ;
	replace l95loggap = r(lb_1) if inflationtarget == `i' ;

	centile unemploymentrate if inflationtarget == `i', centile(50) normal ;

	replace medunempl = r(c_1)  if inflationtarget == `i' ;
	replace u95unempl = r(ub_1) if inflationtarget == `i' ;
	replace l95unempl = r(lb_1) if inflationtarget == `i' ;
} ;

collapse (mean) medloggap u95loggap l95loggap medunempl u95unempl l95unempl, by(inflationtarget) ;

graph twoway (rarea u95loggap l95loggap inflationtarget, lcolor(blue) fcolor(blue) fintensity(inten50)) || (rarea u95unempl l95unempl inflationtarget, lcolor(red) fcolor(red) fintensity(inten50)), 
	ylabel(0.05(0.025)0.15) 
	xlabel(0(1)10) 
	xtitle("Target inflation rate, percent") ytitle("Median values")
	legend(order(1 2) rows(1) label(1 "Output gap") 
					  label(2 "Unemployment rate") size(small)) 
	graphregion(color(white) margin(0 0 0 1)) bgcolor(white) ;

graph export fig2a.pdf, as(pdf) replace ;


/**********************************************************************************************************************************************
 * GRAPH SHOWING THE BOX-WHISKER PLOTS FOR THE DISTRIBUTIONS OF THE LOG OUTPUT GAP AND THE UNEMPLOYMENT RATE ACROSS RUNS PER INFLATION TARGET *
 **********************************************************************************************************************************************/
 
# delimit ; 
 
use exp_results_history.dta, clear ;

drop if crashed == 1 ;

graph box logoutputgap unemploymentrate, over(inflationtarget, label(ticks)) nooutsides 
    box(1, bfcolor(blue) blcolor(blue)) box(2, bfcolor(red) blcolor(red))
	ytitle("Percentile values") 
	note("")
	legend(order(1 2) rows(1) label(1 "Output gap") label(2 "Unemployment rate") size(small)) 
	graphregion(color(white) margin(0 0 0 1)) bgcolor(white) ;

graph export fig2b.pdf, as(pdf) replace;
